package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````(`/@`!````F!Y```````!``````````(">````
M`````````$``.``(`$``'``;``8````$````0`````````!``$```````$``
M0```````P`$```````#``0````````@``````````P````0``````@``````
M```"0`````````)````````5`````````!4``````````0`````````!````
M!0````````````````!``````````$```````.B8````````Z)@`````````
M$`````````$````&````Z)@```````#HJ$```````.BH0```````4`0`````
M``#Y!``````````0`````````@````8```#HF````````.BH0```````Z*A`
M`````````@`````````"````````"``````````$````!````!@"````````
M&`)````````8`D```````#@`````````.``````````$`````````%#E=&0$
M````#)@````````,F$````````R80```````W`````````#<``````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$``````````O;&EB97AE8R]L9"UE;&8N<V\N,@`````*````
M!`````$```!$<F%G;VY&;'D```"(*`D`"@````0````@````1')A9V]N1FQY
M`````````````````````````````````````````#T````2````````````
M`````````````$X````2`````````````````````````%0````2````````
M`````````````````%L````2`````````````````````````&,````2````
M`````````````````````&H````2`````````````````````````'(````2
M`````````````````````````)`````2`````````````````````````)H`
M```2`````````````````````````*$````2````````````````````````
M`*@````2`````````````````````````+$````2````````````````````
M`````+\````2`````````````````````````,0````2````````````````
M`````````,X````2`````````````````````````-P````2````````````
M`````````````/$````2``````````````````````````0!```2````````
M`````````````````!,!```2`````````````````````````"L!```2````
M`````````````````````$L!```2`````````````````````````&4!```2
M`````````````````````````'0!```2`````````````````````````(<!
M```2`````````````````````````(\!```2````````````````````````
M`)L!```2`````````````````````````*(!```2````````````````````
M`````+<!```2`````````````````````````+X!```2````````````````
M`````````,H!```2`````````````````````````.0!```2````````````
M`````````````/4!```2``````````````````````````4"```2````````
M``````````````````H"```2`````````````````````````!$"```2````
M`````````````````````!<"```2`````````````````````````!P"```2
M`````````````````````````","```2`````````````````````````"P"
M```2`````````````````````````#$"```2````````````````````````
M`#8"```2`````````````````````````#X"```2````````````````````
M`````%`"```2`````````````````````````%@"```6````````````````
M`````````%X"```2`````````````````````````&8"```2````````````
M`````````````&X"```2`````````````````````````'0"```2````````
M`````````````````(@"```2`````````````````````````*$"```2````
M`````````````````````+4"```2`````````````````````````+X"```2
M`````````````````````````,0"```2`````````````````````````,L"
M```2`````````````````````````.P"```2````````````````````````
M``,#```2`````````````````````````$X#```2````````````````````
M`````'4#```2`````````````````````````)@#```2````````````````
M`````````*8#```2`````````````````````````,`#```@````````````
M`````````````-H#```@`````````````````````````(`#```2````$!I`
M``````````````````$$```1`!0`^*Q````````(`````````'L!```2``P`
M$#=```````!>`````````'L"```2``P`8"U````````\!P```````/P#```2
M``P`(!Q```````#L`0```````!L$```2``T`N%%``````````````````#`#
M```2``P`0"A```````#O`0```````#T#```2``P`,"A````````#````````
M`%\#```2``P`H#1```````!O`@```````/8#```2``H`$!A`````````````
M``````8````0`!$`.*U```````````````````$````0`!$`X:U`````````
M`````````.H!```2``P`\$U```````"@`0```````(\"```2``P`H"Q`````
M``"Q`````````/4"```2``P`$"Q```````!J`````````",#```2``P`,"I`
M```````B`````````)`#```2``P`L"=````````J`````````#H!```2````
M<!M``````````````````!<#```2``P`8"I```````!$`````````!(````0
M`!$`.*U``````````````````.<````1`!0`$*U````````(`````````%(!
M```2````8!M``````````````````!0$```2``P`F!Y```````!-`0``````
M`/P!```2``P`D$U```````!4`````````+4#```1`!@`P*U````````$````
M``````P$```1`!@`0*U````````(`````````$8"```1`!@`R*U````````(
M`````````-$"```2``P`@"Q````````=`````````-H!```2``P`D$]`````
M``#U`0```````!X!```1`!@`X*U````````!``````````H#```2``P`L"I`
M``````!<`0```````!D````1`!@`@*U```````!```````````!?96YD`%]?
M8G-S7W-T87)T`%]E9&%T80!?7W-T86-K7V-H:U]G=6%R9`!$1C0P-"XP`&QI
M8F,N<V\N.`!?7W-T86-K7V-H:U]F86EL`&%B;W)T`&UA;&QO8P!M96UM;W9E
M`'-T<FQE;@!S=')N8VUP`%]R=&QD7V-A;&Q?:6YI=`!$1G!R:79A=&5?,2XP
M`%]I;FET7W1L<P!M96UC<'D`871E>&ET`'!E<FQ?<G5N`%!E<FQ?<WES7W1E
M<FT`97AI=`!P97)L7V9R964`<&5R;%]D97-T<G5C=`!P97)L7W!A<G-E`&UY
M7W!A<E]P;`!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]C;VYS=')U8W0`<&5R
M;%]A;&QO8P!03%]D;U]U;F1U;7``<'1H<F5A9%]A=&9O<FL`4&5R;%]A=&9O
M<FM?;&]C:P!S='!C<'D`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<WES7VEN
M:70S`'-T<F1U<`!P87)?8VQE86YU<`!S=')R8VAR`%!E<FQ?;6=?<V5T`'-T
M<F-M<`!097)L7V-R;V%K7VYO8V]N=&5X=`!S=')T;VL`4&5R;%]G971?<W8`
M4&5R;%]G=E]F971C:'!V`'-H85]F:6YA;`!C;&]S90!S:&%?=7!D871E`'-T
M<F-H<@!S:&%?:6YI=`!R96%D`'5N;&EN:P!L<V5E:P!S=&%T`&=E='!I9`!C
M;&]S961I<@!O<&5N`&9R964`9G!R:6YT9@!O<&5N9&ER`%]?<W1D97)R<`!R
M96%L;&]C`&5R<FYO`'-P<FEN=&8`<F5A9&1I<@!M:V1I<@!M96UC:'(`<&%R
M7VUK=&UP9&ER`'-T<G-T<@!P87)?<V5T=7!?;&EB<&%T:`!P=&AR96%D7V=E
M='-P96-I9FEC`&=E='!W=6ED`&QS=&%T`&=E='5I9`!R;61I<@!G971?=7-E
M<FYA;65?9G)O;5]G971P=W5I9`!R96%D;&EN:P!P87)?96YV7V-L96%N`&%C
M8V5S<P!P87)?:6YI=%]E;G8`<&%R7V1I<FYA;64`<&%R7V)A<V5N86UE`'!A
M<E]F:6YD<')O9P!P87)?8W5R<F5N=%]E>&5C`%!E<FQ?;F5W6%-?9FQA9W,`
M6%-?26YT97)N86QS7U!!4E]"3T]4`%!E<FQ?;F5W6%,`8F]O=%]$>6YA3&]A
M9&5R`'AS7VEN:70`4&5R;%]S=E]S971P=@!097)L7W-V7W-E='!V;@!03%]T
M:')?:V5Y`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`7TE435]D97)E9VES
M=&5R5$U#;&]N951A8FQE`%]I;FET`&UA:6X`7U]P<F]G;F%M90!E;G9I<F]N
M`%]S=&%R=`!?9FEN:0!L:6)P97)L+G-O+C4N,S(`;&EB<'1H<F5A9"YS;RXP
M`&QI8F1L+G-O+C``;&EB;2YS;RXT`&QI8F-R>7!T+G-O+C0`;&EB=71I;"YS
M;RXT`"]U<W(O;&EB+V=C8S@P.B]U<W(O;&]C86PO;&EB+W!E<FPU+S4N,S(O
M;6%C:"]#3U)%```````1````/P````0````(````(!P0``5`!(`H`$`$D(8!
MC,(A`2!)``0;B((X0;H$`@@_````00```$4```!)````2@```%````!1````
M4@```%0```!5````5@```%<```!9````6P```%P`````````7@```'KP2FN]
M4':>;L7?'\[>1RUJ?YI\Z]/O#B#_Y`XNQ9NVU&34?+F-\0[9<5@<NN.2?$+Z
MUX?ZH6Q@L@&+;^)'Q@'#Y3\LA_F<@6>OS&9"1=7LB0=PT\G5LG$S8MOM%8PE
MS%:DFY:GW:-KYA4#@W^IG)MK&IY0"HH05Z/@^TDA8F0'```"``(``@`"``(`
M`@`#``,``@`"```````"``````````````````(``@````(``@````(````"
M```````"``(``@`"``(``@`"``(``@`"``(``@`"``(``@`"``(``@`"``(`
M`@`"``(``@`"``(````````````````````!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!`````0`!``$````!``$``0`!``(``0`!``$``0`"````
M`0`"`#,````0`````````%`WEP@```(`*P```!````"0M'X````#`((`````
M`````````.BJ0```````$@```"P``````````````,"M0```````!0```%<`
M`````````````,BM0```````!0```%D``````````````."M0```````!0``
M`%P``````````````("M0```````!0```%X```````````````BK0```````
M!P````(``````````````!"K0```````!P````@``````````````!BK0```
M````!P````<``````````````""K0```````!P````H``````````````"BK
M0```````!P````T``````````````#"K0```````!P````8`````````````
M`#BK0```````!P````$``````````````$"K0```````!P````4`````````
M`````$BK0```````!P````,``````````````%"K0```````!P````0`````
M`````````%BK0```````!P```"L``````````````&"K0```````!P```"H`
M`````````````&BK0```````!P```"X``````````````'"K0```````!P``
M`"T``````````````'BK0```````!P```"0``````````````("K0```````
M!P```"(``````````````(BK0```````!P```"@``````````````)"K0```
M````!P```"8``````````````)BK0```````!P```#8``````````````*"K
M0```````!P```#0``````````````*BK0```````!P```#@`````````````
M`+"K0```````!P```#<``````````````+BK0```````!P```#``````````
M`````,"K0```````!P```#(``````````````,BK0```````!P```#P`````
M`````````-"K0```````!P```#L``````````````-BK0```````!P```!4`
M`````````````."K0```````!P```!@``````````````.BK0```````!P``
M`!<``````````````/"K0```````!P```#\``````````````/BK0```````
M!P```"````````````````"L0```````!P```!P```````````````BL0```
M````!P```!H``````````````!"L0```````!P```#4``````````````!BL
M0```````!P```#,``````````````""L0```````!P```#$`````````````
M`"BL0```````!P```"\``````````````#"L0```````!P```"D`````````
M`````#BL0```````!P```"<``````````````$"L0```````!P```"4`````
M`````````$BL0```````!P```",``````````````%"L0```````!P```"$`
M`````````````%BL0```````!P```!\``````````````&"L0```````!P``
M`!X``````````````&BL0```````!P```!T``````````````'"L0```````
M!P```!L``````````````'BL0```````!P```!D``````````````("L0```
M````!P```#H``````````````(BL0```````!P```#D``````````````)"L
M0```````!P```!8``````````````)BL0```````!P```%0`````````````
M`*"L0```````!P```%```````````````*BL0```````!P```!0`````````
M`````+"L0```````!P```!,``````````````+BL0```````!P```!(`````
M`````````,"L0```````!P```!$``````````````,BL0```````!P```!``
M`````````````-"L0```````!P````\``````````````-BL0```````!P``
M``X``````````````."L0```````!P````P``````````````.BL0```````
M!P````L``````````````/"L0```````!P````D``````````````$B#[`CH
MBP@``.AG.0``2(/$",,`````````````````_S7"D@``_R7$D@``D)"0D/\E
MPI(``&@`````Z>#_____);J2``!H`0```.G0_____R6RD@``:`(```#IP/__
M__\EJI(``&@#````Z;#_____):*2``!H!````.F@_____R6:D@``:`4```#I
MD/____\EDI(``&@&````Z8#_____)8J2``!H!P```.EP_____R6"D@``:`@`
M``#I8/____\E>I(``&@)````Z5#_____)7*2``!H"@```.E`_____R5JD@``
M:`L```#I,/____\E8I(``&@,````Z2#_____)5J2``!H#0```.D0_____R52
MD@``:`X```#I`/____\E2I(``&@/````Z?#^____)4*2``!H$````.G@_O__
M_R4ZD@``:!$```#IT/[___\E,I(``&@2````Z<#^____)2J2``!H$P```.FP
M_O___R4BD@``:!0```#IH/[___\E&I(``&@5````Z9#^____)1*2``!H%@``
M`.F`_O___R4*D@``:!<```#I</[___\E`I(``&@8````Z6#^____)?J1``!H
M&0```.E0_O___R7RD0``:!H```#I0/[___\EZI$``&@;````Z3#^____)>*1
M``!H'````.D@_O___R7:D0``:!T```#I$/[___\ETI$``&@>````Z0#^____
M)<J1``!H'P```.GP_?___R7"D0``:"````#IX/W___\ENI$``&@A````Z=#]
M____);*1``!H(@```.G`_?___R6JD0``:",```#IL/W___\EHI$``&@D````
MZ:#]____)9J1``!H)0```.F0_?___R62D0``:"8```#I@/W___\EBI$``&@G
M````Z7#]____)8*1``!H*````.E@_?___R5ZD0``:"D```#I4/W___\E<I$`
M`&@J````Z4#]____)6J1``!H*P```.DP_?___R5BD0``:"P```#I(/W___\E
M6I$``&@M````Z1#]____)5*1``!H+@```.D`_?___R5*D0``:"\```#I\/S_
M__\E0I$``&@P````Z>#\____)3J1``!H,0```.G0_/___R4RD0``:#(```#I
MP/S___\E*I$``&@S````Z;#\____)2*1``!H-````.F@_/___R4:D0``:#4`
M``#ID/S___\E$I$``&@V````Z8#\____)0J1``!H-P```.EP_/___R4"D0``
M:#@```#I8/S___\E^I```&@Y````Z5#\____)?*0``!H.@```.E`_/___R7J
MD```:#L```#I,/S___\EXI```&@\````Z2#\____)=J0``!H/0```.D0_/__
M4TB#[#!(BP54D0``2(E$)"@QP(E\)!Q(C7PD'$B)="002(UT)!!(B50D"$B-
M5"0(Z/O^__^Z8!M``+]P&T``2(G6Z!G___^`/7*1````=2_H&____TB)!?20
M``!(A<`/A'@!``!(B<?H$____XL]+9$``.@8_?__QH`1"0```(L]&Y$``.@&
M_?__BST0D0``@(C"`P```NCT_/__@(C"`P```8M$)!R->`2-6`-(8_](P><#
MZ-?^__](BWPD$$2+1"0<2(D%?I```$B+%TC'0`B<4T``2,=`&)]30`!(B1!(
MBQ4)D```2(E0$$&#^`$/CMT```!(@\<(08/``[X$````3(L/2&/6@\8!2(/'
M"$R)#-!!.?!UZDUCP$G!X`-*QP0``````$B+/2*0``")VD4QP$B)P;[@)T``
MZ&#^__^)PX7`=$E(BST#D```Z%[^__\QP$B-="0DOVI20`#H/0,``$B%P'0W
M2(L]X8\``.A,_O__Z%?^__^)V$B+3"0H2#,-V8\``'5>2(/$,%O#2(L]NH\`
M`.A%_O__B</KITB+/9J/``!(A?]T!^A`&0``Z[:_&%)``$B-="0DZ-\"``!(
MB<=(B05UCP``2(7`=)CKV4&X(````.E"____OP$```#H>?K__^B4^O__N```
M``!(/0````!S.E5(B>5!5%.#/>'AO_\E=2!(B<-,BR/_4Q!)B00D2(/#&$B!
M^P````!S"X-[""5TX^CR^?__6T%<7</#54B)Y5-(@^P(N`````!(+0````!(
MP?@#2(G#=1'H0C,``$B#Q`A;7<-(A=MT[TB#ZP%(BP3=`````$B#^`%VZ?_0
MZ^552(GE05=!5D%505132(/L&$B)\TR++T6)[TR-=PA)8\5,C63'$$B#/7J.
M````=%=%A>U^%TB+1PA(A<!T#DB)!1N.```/MA"$TG5/Z&?Y___H<OG__[CH
MJ$``2(7`=$U(B=_H</G__[CHJ$``2(7`=$),B>),B?9$B>_H"/W__XG'Z&'Y
M__],B24:C@``ZZ!(@\`!#[80A-)TL8#Z+W7P2(U0`4B)%;6-``#KX^C"_O__
MZ[2_5!Y``.@:^?__N`````!(+0````!(P?@#2(E%R'0LNP````#K"DB#PP%(
M.5W(=!M(BP3=`````$B#^`%VZ$R)XDR)]D2)___0Z]OH=/C__[@`````2"T`
M````2,'X`TB)1<@/A%7___^[`````.L.2(/#`4@Y7<@/A$#___](BP3=````
M`$B#^`%VY$R)XDR)]D2)___0Z]>X.*U``$@].*U``'07N`````!(A<!T#55(
MB>6_.*U``/_07</#OCBM0`!(@>XXK4``2,'^`TB)\$C!Z#](`<9(T?YT%[@`
M````2(7`=`U52(GEOSBM0`#_T%W#PX`]`(T```!U655(B>5!5%.[,*U``$B!
MZRBM0`!(P?L#2(/K`4&\**U``$B+!=Z,``!(.=AS&TB#P`%(B07.C```0?\4
MQ$B+!<.,``!(.=ARY>A.____Q@6JC````5M!7%W#PU5(B>7H7?___UW#9F9F
M9BX/'X0```````````!!5T%6055!5%532(/L"$B%_P^$JP```$R+/6*,``!-
MA?\/A)L````/M@>$P'0$/#UU7D4QY$F+'TB%VW0Y28GU28G^36/D3(G]#Q^`
M`````$R)XDR)]DB)W^AR]___A<!U!T*`/",]=$=(@\4(2(M=`$B%VW7:2(/$
M"$B)V%M=05Q!74%>05_##Q^$``````!)B?Q)@\0!00^V!"2$P'0$/#UU[T$I
M_.N,#Q^``````$PI_4J-7",!2,']`T&);0#KM#';Z[!F+@\?A```````4TB)
M^TB#[!!(BP7ABP``2(E$)`@QP&8N#Q^$```````QP$B-="0$2(G?Z`'___](
MA<!T+DAC5"0$2(L%<(L``$B-!-!(BU`(2(D02(72=-!(@\`(2(M0"$B)$$B%
MTG7PZ[Y(BT0D"$@S!8*+``!U!DB#Q!!;P^B5]O__#Q]$``!!5T%6055!5%5(
MB?532(G[2(/L*$B+!56+``!(B40D&#'`,<"`/CT/E,!(`<5(B>_H:_;__TB-
M="042(G?28G$,<#H:?[__TB%P`^$!`$``$B)QTF)Q>A%]O__3#G@#X/0````
M3&-T)!1)P>8##[8#A,`/A)P!```\/0^$E`$``$B)V$B#P`$/MA"$TG0%@/H]
M=?!(*=A(F$J-?"`"3`,UC(H``.@']O__28D&2(7`#X1S`0``2(L%=(H``$AC
M5"042(U+`4B+%-`/M@.(`H3`="0\/74.ZQX/'X0``````(3`=!)(@\$!#[9!
M_TB#P@&(`CP]=>K&`CTQP`\?1```#[9,!0"(3`(!2(/``83)=>\QP$B+7"08
M2#,=48H```^%#0$``$B#Q"A;74%<05U!7D%?PS'`9BX/'X0```````^V5`4`
M08A4!0!(@\`!A-)U[NN]3(L]U8D``$F#/P`/A+8```!,B?@QTNL'#Q]``$2)
MZDB#P`A$C6H!2(,X`'7OC7(#2&/V2,'F`XL%MXD``(7`=5O'!:F)```!````
M2(GWZ`GU__](A<!T?$UCQ4R)_DB)QTZ--,4`````3(E$)`A,B?+H]O3__TR+
M1"0(2(D%6HD``$B)P4K'1,$(`````$2);"04Z8'^__\/'T``3(G_Z-CT__](
MB<%(B04NB0``2(7`="%-8\5.C33%`````.O%,<#I??[__[X0````13'MZ6/_
M__^X_____^GA_O__Z%GT__]F#Q^$``````!!54%455-(@>R8````2(L%'(D`
M`$B)A"2(````,<!(A?]T"(`_`$B)_74E2(N$)(@```!(,P7VB```#X7\````
M2('$F````%M=05Q!7<-FD.A+]/__28G$2(7`=,Y,B>?H2_3__TB%P`^$L@``
M`$B-6!"_R5%``+D"````2(G>\Z8/E\`<`(3`=-._RU%``+D#````2(G>\Z8/
ME\`<`(3`=+M(B>_HMO/__TB)WTF)Q>BK\___08U\!0)(8__HKO/__TB)V4B)
MZK[.44``28G%2(G',<#HYO/__TR)[TB)YNCK\___3(GO@_C_=`\/MT0D$&8E
M`/!F/0!`=#GHW_/__TR)[^CG\___3(GGZ)_S__](A<`/A53___]F#Q]$``!,
MB>?HV//__TB)[^C@\___Z?;^___HQO[__^O%Z`_S__]F9BX/'X0```````\?
M0`!32(G[2('LD````$B+!<Z'``!(B80DB````#'`2(GFZ*SS__^%P'4X#[=4
M)!"!X@#P``"!^@!```!T"('Z`*```'4?O@(```!(B=_HD//__X7`#Y3`#[;`
MZPAF#Q]$```QP$B+C"2(````2#,-;X<``'4)2('$D````%O#Z'_R__]F9BX/
M'X0```````\?0`!!5;K_`P``28GU05152(G]O]110`!32('L&`0``$B+!2R'
M``!(B80D"`0``#'`2(GFZ"KS__^%P'YKC5#_1(LE3(<``$ACVH`\'`!U4X72
M=%M(B=J^+P```$B)Y^@/\___2(7`=$9$B>?H$O/__TB)V4B)XDB)[DB)Q^@1
M\___2(N$)`@$``!(,P7"A@``=31(@<08!```6UU!7$%=PV:02&/8ZZQ$BR7D
MA@``1(GGZ,SR__],B>I(B>Y(B<?HWO+__^N[Z*?Q__\/'X``````4TB)_DB!
M[!`$``!(BP5NA@``2(F$)`@$```QP$B)XTB)W^BY\O__2(/H`4@YV'<.ZQ'&
M``!(@^@!2#G8=`6`."]T[[XO````2(G?Z*#R__](A<!T,$@YV'<F2(G?Z)[R
M__](BY0D"`0``$@S%0^&``!U-4B!Q!`$``!;PP\?0`#&``#KU4B+A"0(!```
M2#,%[(4``'422('$$`0``+_)44``6^E8\O__Z//P__\/'P!(@^P(BST&A@``
MZ/'Q__^YL))``+H0&D``ON=10`!(B<=(@\0(Z5;S__]F#Q]$``!(@^P(BSW6
MA0``Z,'Q__](B<?HN?___XL]PX4``.BN\?__0;C(44``13')NJ`T0`!,B<&^
M`U)``$B)QTB#Q`CI'//__V9F+@\?A```````D#'`PV9F+@\?A```````9I!!
M54F)_;\84D``05154TB)\TB![)@$``!(BP4AA0``2(F$)(@$```QP$B)YNA/
M^/__OB\```!,B>](B<7HG_'__TB%P'0Z3(GNOR%20``QP.A[^?__3(GH2(N4
M)(@$``!(,Q79A```#X5]`0``2('$F`0``%M=05Q!7<,/'T0``$B)W^@X\?__
MOBY20`!(B<?H6_'__TB)PTB%P'2I@#L`#X3;````9BX/'X0``````$B%[703
M2(G>2(GOZ$#Q__^%P`^$F````$B)W^B@[___2(U,`_])B<1(.<MS(X`Y+W0'
MZQR`.2]U#,8!`$B#Z0%(.<MU[TB)W^AS[___28G$3(GOZ&CO__])C40$`4@]
M_P,```^'+?___[XR4D``,<!-B>BY,%)``$B-O"2`````2(G:Z)CO__](B>9(
MC;PD@````.B8[___A<!U%`^W1"009B4`\&8]`(!T50\?1```OBY20``Q_^B$
M\/__2(G#2(7`#X3._O__@#L`#X4O____2(7M=!FY`@```+_)44``2(GN\Z8/
ME\*`V@"$TG3!0;P!````N\E10`#I4?___Y"^`0```$B-O"2`````Z'[O__^%
MP'6:2(VT)(````"_(5)``.CX]___2(V\)(````#HV^___^EN_O__Z''N__^0
M4[XO````2(G[Z++O__](C5`!2(7`2`]%VDB)WUOIKN___V9F+@\?A```````
M#Q\`2(7_="N`/P!T)E-(B?OH/>[__TB#P`%(/0`$``!W(4B)WUOI>/S__P\?
MA```````O\E10`#I9N___V8/'T0``#'`6\-F9BX/'X0``````)!(@^P8OSE2
M0`!(BP7`@@``2(E$)`@QP.C$]O__,<"_0E)``.BX]O__,<"_2E)``.BL]O__
M,<"_4U)``.B@]O__,<"_6E)``.B4]O__,<"_:E)``.B(]O__,<"_&%)``.A\
M]O__,<"_=E)``.AP]O__,<"_@%)``.AD]O__,<"_BE)``.A8]O__,<"_(5)`
M`.A,]O__,<!(C70D!+^44D``Z&OU__](A<!T#TB)QK^`4D``,<#HI_;__S'`
M2(UT)`2_I5)``.A&]?__2(7`=`](B<:_MU)``#'`Z(+V__\QP$B-="0$O\)2
M0`#H(?7__TB%P'0\2(G&OQA20``QP.A=]O__,<"^XU)``+]:4D``Z$SV__](
MBT0D"$@S!;"!``!U-4B#Q!C#9@\?A```````,<!(C70D!+_24D``Z,_T__](
MA<!TO4B)QK]V4D``,<#H"_;__^NLZ)3L__\/'T``2(/L&$B+!66!``!(B40D
M"#'`BP7@@```@_C_=!-(BW0D"$@S-4>!``!U.DB#Q!C#2(UT)`2_=E)``#'`
MZ&_T__](B<(QP$B%TG02#[82@/HP#Y7!,<"$T@^5P"'(B065@```Z[CH)NS_
M_V8/'T0``$B#[`CHQ^W__XG'Z-#M__](A<!T`TB+`$B#Q`C##Q\`05152(G]
MO^520`!32(/L$$B+!<F```!(B40D"#'`2(UT)`3H^//__TB)[DB%P'0(@#@`
M2(G#=2B_Y5)``#'`Z"SU__](BT0D"$@S!9"```!U6DB#Q!!;74%<PP\?1```
M2(G'Z&CM__](A<!UUTB)[^B;Z___2(G?28G$Z)#K__])C7P$`NB6Z___OC)2
M0`!)B=A(B>I)B<1(B<>Y+E)``#'`Z,GK__],B>;KC.A/Z___9F8N#Q^$````
M```/'T``059!54F)_;\84D``05154TB![&"!``!(BP4"@```2(F$)%B!```Q
MP$B-="002,>$))`````!4T``2,>$))@```#)44``2,>$)*``````````2,>$
M)-````"W4D``2,>$)-@````'4T``2,>$).`````.4T``2,>$).@````64T``
M2,>$)/`````;4T``2,>$)/@`````````2,>$)+````#U4D``2,>$)+@````?
M4T``2,>$),``````````Z)[R__](A<!T"8`X``^%8`0``#'`Z$G^__](B<-(
MA<`/A-T#``!(B=_H9>K__TB-?``!Z&OJ__^`.P!)B<1T(DR)Y0^V$TB)[S'`
MOBA30`!(@\,!2(/%`NB6ZO__@#L`=>%(C9PDV````+^W4D``ZQ-FD$B#PPA(
MBWOX2(7_#X1S`0``2(UT)!`QP.@3\O__2(G%2(7`=-N`.`!TUDB)Q^C>]O__
MA<!TRDB)[^@RZ___2(G#2(7`#X0Z`0``9@\?1```2(G>BQ9(@\8$C8+__O[^
M]](AT"6`@("`=.F)PL'J$*F`@```#T3"2(U6`D@/1/*)P0#!3(GA2(/>`T@I
MWHLY2(/!!(V'__[^_O?7(?@E@("`@'3IB<+!ZA"I@(````]$PDB-40)(#T3*
MB<(`PDB#V0-,*>&-K`X$!```2&/M2(GOZ%KI__^^,E-``$V)X4B)VDB)QTF)
MQD&X+5-``#'`N3!20`#HA^G__[[``0``3(GWZ.KJ__^#^/]U'F1(BQ0E````
M`$B+!3U[``!$BP0"08/X$0^%M0(``$B-="003(GWZ*KI__^)PX7`#X2P````
M28M5`$B+/>U]``!,B?$QP+[P4T``,>WHI.K__TB+C"18@0``2#,-A7T``$B)
MZ`^%DP0``$B!Q&"!``!;74%<05U!7L,Q[68N#Q^$``````!(8\5(BYS$D```
M`$B%VW1`@#L`=#M(B=^#Q0'H8/7__X7`=-Q(B=_HM.G__TB)PTB%P`^%B/[_
M_TACQ4B+G,20````2(7;=<@/'X0``````#';Z6G^__]F#Q^$```````/MT0D
M(&8E`/!F/0!`#X4]____1(MD)"3HL^G__T$YQ`^%*O___P^W1"0@9B7_`68]
MP`$/A1?___](B>_H_^?__TB-="00OSM30`!(B<4QP.CK[___2(7`#X3R`0``
M28M]`$B)QNA6]___28G$2(7`#X3:`0``3(GGZ++G__^#^`-^/4ACT+]`4T``
MN04```!)C704_/.F#Y?"@-H`A-)U'X/X!`^$N0(``(/H!$B808!\!/\O#X2H
M`@``#Q]$```QP.C)^O__A<!U%4R)YS'VZ$OI__]!B<2%P`^%>0$``+[C4D``
MOW920``QP.B?\/__Z#KI__^Y,%)``$R)\DB)[T&)P$&YR%%``+Y94T``,<#H
M>N?__^M.#Q^$``````!D2(L4)0````!(BP4X>0``@SP"$75"Z/7H__](@^P(
M@\,!3(GR:,A10`!!B<!!B=FY,%)``+YG4T``2(GO,<#H+.?__UA:OL`!``!(
MB>_HC>C__X/X_W2H3(GWZ$#G__](B>Z_&%)``#'`Z`'P__](B>_HB?K__^G0
M_?__#Q]``+_U4D``,>WK$@\?@`````!(8\5(B[S$L````$B%_W1R2(UT)!`Q
MP(/%`>AQ[O__2(7`=-R`.`!TUTB)Q^B?Y___2(G#2(7`=,?IU?O__TF+50!(
MBSU/>P``3(GQ,<"^J%-``#'MZ`;H___I7?W__Y!(B<=(B40D".@#^O__2(M$
M)`A(B<?H5N?__TB)Q>DZ_?__OPT```"[^E)``.C_Y?__28G$Z93[__\/'X``
M````38ME`.D=_O__N@(```!(Q\;N____B<?HU.?__[H&````2(VT)%`!``!$
MB>?HS^?__X"\)%`!````=0Z`O"11`0``0P^$"@$``#'2,?9$B>?HF^?__S'`
MZ&0:``!(B</K$HG"2(VT)%`!``!(B=_HK1H``+H`@```2(VT)%`!``!$B>?H
M>.?__X7`?]5$B>=,C:0D``$``.ATY___2(G>2(V\)``!``!(C9PD(`$``.@,
M'```3(UK*`\?A```````00^V%"1(B=^^*%-``#'`2(/#`DF#Q`'H9.7__TDY
MW77?QH0D2`$```!!N<A10`!,C80D(`$``+DP4D``3(GRODI30`!(B>\QP.@R
MY?__Z17^__]-BVT(387M#X10_?__3(GOZ+CD__](@_@##X8^_?__28UT!?R_
M15-``+D%````\Z8/E\`<`(3`30]$Y>D=_?__@+PD4@$``$$/A>C^__^`O"13
M`0``0P^%VO[__X"\)%0!``!(#X7,_O__@+PD50$``$4/A;[^__^Z`@```$C'
MQL;___]$B>?H4>;__[HI````2(VT)%`!``!$B>?H3.;__T&YR%%``$R-A"10
M`0``Z3#____H!.3__P\?0`!54TB#[!B+/11Y``!(BP7->```2(E$)`@QP.CQ
MY/__BSW[>```2(G#Z./D__](C70D!+]:4D``#[:3N````(B0N0```#'`Z-7K
M__](A<!T"8`X,0^$EP$``#'`Z+#U__^+/;IX``#HI>3__[D#````N@$```"^
M>%-``$B)Q^C.Y?__2(G#2(7`=#-(BT`0BSV,>```2(LHZ'3D__^Z>E-``$B)
MQTB)[NB$Y/__2(M#$$B+&/9##D`/A7,!``"+/5UX``#H2.3__[D#````N@$`
M``"^?U-``$B)Q^AQY?__2(G#2(7`=#U(C70D!+\A4D``,<#H*.O__TB)Q4B%
MP`^$_````$B+0Q"+/1)X``!(BQCH^N/__TB)ZDB)WDB)Q^@,Y/__BSWV=P``
MZ.'C__^Z`0```+Z!4T``2(G'Z!_E__^+/=EW``!(B</HP>/__[J64T``2(G>
M2(G'Z-'C__^+/;MW``#HIN/__TB-="0$OQA20`#&@+D`````,<#HGNK__TB)
M!3=W``!(A<!T-[[``0``2(G'Z$7D__^-4`&#^@%V"8/X$0^%GP```$B+1"0(
M2#,%*'<```^%K````$B#Q!A;7<-(BSW\=@``Z._V__](B07H=@``2(7`=;&_
M2%1``.B)Y/__9@\?A```````@'@!``^$9O[__^E:_O__D$B+!<%V``"+/1-W
M``!(BRA(BT,02(L8Z/3B__](B>Y(B=_H:>___^GX_O__#Q]``(L]ZG8``.C5
MXO__2(G>2(G'Z#KD___I<O[__XG!2(L%='8``$B+%65V``"_<%1``$B+,#'`
MZ`;D___HD>'__Y!54TB)^TB#[`CH0O/__TB)Q^@*\___2(G%,<#HX/3__X7`
M=")(A=MT'8`[`'08ORU30`"Y!````$B)[O.F#Y?`'`"$P'0*2(/$"%M=PP\?
M`$B#Q`A(B=];7>GB[/__9I`/'T``````````````````05=,C4\X059!54%4
M55-(@>R8`@``2(L%Y'4``$B)A"2(`@``,<!(B>),C9*`````28G008L!28LQ
M28/`$$F#P0@/R(G`2(GQ28E`\$B)\$C!Z2!(P>@H2,'N."4`_P``2`GP2(G.
M2,'A"$C!YAB!X0``_P")]D@)\$@)R$F)0/A-.<)UKDB-L@`"```/'T``2(M"
M:$@S0D!(@\((2#-""$@S0OA(C0P`2,'H'T@)R(/@_TB)0GA(.?)UU4R+%TB+
M7Q!(BW<@2(MO&$R)T$R)TDR+3PA(P>H;2,'@!4@)T`,$)(V4,)EY@EI(B=A(
MBW0D"$@QZ$PAR$B-M#69>8):2#'H1(TL`DR)RDR)R$C!Z`)(P>(>38GH2`G"
M2(G82<'H&XG12#'(3"'02#'82`'P3(GN2,'F!4P)QD2-)`9,B=9,B=!(P>8>
M2,'H`DV)XT@)\$B+="002<'K&T@QPD&)P$PAZDB-M#.9>8):2#'*2`'R3(GF
M2,'F!4P)WD2-'!9,B>Y)P>T"2(M4)!A(P>8>3`GN2(V4$9EY@EI,B=E(,?!!
MB?9,(>!,,<!(P>D;2`'03(G:2,'B!4@)RDR)X4G![`)(P>$>1(TL`DB)\$B+
M5"0@3`GA3(GN2#'(28V4$)EY@EI(P>X;08G,3"'83#'P2`'03(GJ2,'B!4@)
M\D2-!`),B=I)P>L"2(M$)"A(P>(>3(G&3`G:28V$!IEY@EI(P>X;2#'108G3
M3"'I3#'A2`'!3(G`2,'@!4@)\$2--`A,B>A)P>T"2(M,)#!(P>`>3(GV3`GH
M28V,#)EY@EI(,<)!B<5,(<),,=I(`<I,B?%(P>$%2,'N&T@)\4R)QDG!Z`)(
MP>8>1(TD$4B+5"0X3`G&3(GA2#'P28V4$YEY@EI(P>D;08GP3"'P3#'H2`'0
M3(GB2,'B!4@)RDR)\4G![@)(P>$>1(T<`DB)\$B+5"1`3`GQ3(G>2#'(28V4
M%9EY@EI(P>X;08G.3"'@3#'`2`'03(G:2,'B!4@)\D2-+`),B>))P>P"2(M$
M)$A(P>(>3(GN3`GB28V$`)EY@EI(P>X;2#'108G43"'93#'Q2`'!3(GH2,'@
M!4@)\$2-!`A,B=A)P>L"2(M,)%!(P>`>3(G&3`G828V,#IEY@EI(P>X;2#'"
M08G#3"'J3#'B2`'*3(G!2,'A!4@)\4R)[DG![0)(P>8>1(TT$4B+5"183`GN
M3(GQ2#'P28V4%)EY@EI(P>D;08GU3"'`3#'82`'03(GR2,'B!4@)RDR)P4G!
MZ`)(P>$>1(TD`DB)\$B+5"1@3`G!3(GF2#'(28V4$YEY@EI(P>X;08G(3"'P
M3#'H2`'03(GB2,'B!4@)\D2-'`),B?)(BT0D:$C!XAY)P>X"3(G>3`GR28V$
M!9EY@EI(P>X;2#'108G63"'A3#'!2`'!3(G82,'@!4@)\$2-+`A,B>!)P>P"
M2(M,)'!(P>`>3(GN3`G@28V,")EY@EI(P>X;2#'"08G$3"':3#'R2`'*3(GI
M2,'A!4@)\4R)WDG!ZP)(P>8>1(T$$4B+5"1X3`G>3(G!2#'P28V4%IEY@EI(
MP>D;08GS3"'H3#'@2`'03(G"2,'B!4@)RDR)Z4G![0)(P>$>1(TT`DB)\$B+
ME"2`````3`GI3(GV2#'(28V4%)EY@EI(P>X;08G-3"'`3#'82`'03(GR2,'B
M!4@)\D2-)`),B<))P>@"2(N$)(@```!(P>(>3(GF3`G"28V$`YEY@EI(P>X;
M2#'108G03"'Q3#'I2`'!3(G@2,'@!4@)\$B+M"20````1(T<"$R)\$G![@)(
MP>`>28VT-9EY@EI-B=U,"?!)P>T;2#'"B<%,(>),,<)(`?),B=Y(P>8%3`GN
MB?9(`?),B>9)P>P"2,'F'D&)U4P)YDR+I"28````2#'P3"'83XV$()EY@EI-
MB>Q(,<A)P>P;3`'`38GH2<'@!4T)X$6)P$P!P$V)V$G!ZP))P>`>08G$30G8
M28GSB?9(`[0DJ````$TQPT0QVDR+G"2@````2HV,&:'KV6Y-B>-(`=%,B>))
MP>L;2,'B!4P)VHG22`'13(GJ2<'M`DC!XAY!B<M,">I-B<5%B<!,`X0DL```
M`$DQU40QZ$V)W4B-M`:AZ]EN3(G82<'M&TC!X`5,">B)P$@!\$R)YDG![`)(
MP>8>08G%3`GF28G4B=)),?1$,>%-B>Q(`Y0DN````$V-A`BAZ]EN3(GI2<'L
M&TC!X05,">&)R4D!R$R)V4G!ZP)(P>$>18G$3`G928GSB?9(`[0DP````$DQ
MRT0QV$V)XTB-E`*AZ]EN3(G@2<'K&TC!X`5,"=B)P$@!PDR)Z$G![0)(P>`>
M08G33`GH28G-B<E(`XPDR````$DQQ44QZ$V)W4Z-A`:AZ]EN3(G>2<'M&TC!
MY@5,">Z)]DP!QDV)X$G![`))P>`>08GU30G@28G$B<!-,<1$,>)-B>Q(C8P1
MH>O9;DR)ZDC!X@5)P>P;2`.$)-````!,">*)TD@!T4R)VDG!ZP)(P>(>08G,
M3`G:38G#18G`3`.$)-@```!),=-$,=Y-B>-(C;0PH>O9;DR)X$G!ZQM(P>`%
M3`G8B<!(`?!,B>Y)P>T"2,'F'D&)PTP)[DF)U8G22`.4).````!),?5$,>E-
MB=U-C80(H>O9;DR)V4G![1M(P>$%3`GIB<E)`<A,B>%)P>P"2,'A'D6)Q4P)
MX4F)](GV23',1#'@38GL2(V4`J'KV6Y,B>A)P>P;2,'@!4P)X(G`2`'"3(G8
M2<'K`D@#M"3H````2,'@'D&)U$P)V$F)RXG)2`.,)/````!),<-%,=A-B>-.
MC80&H>O9;DR)YDG!ZQM(P>8%3`G>B?9,`<9-B>A)P>T"2<'@'D&)\TT)Z$F)
MQ8G`2`.$)/@```!-,<5$,>I-B=U(C8P1H>O9;DR)VDG![1M(P>(%3`GJB=)(
M`=%,B>))P>P"2,'B'D&)S4P)XDV)Q$6)P$DQU$0QYDV)[$B-M#"AZ]EN3(GH
M2<'L&TC!X`5,">")P$@!\$R)WDC!YAY)P>L"08G$3`.$)``!``!,"=Y)B=.)
MTD@#E"0(`0``23'S1#'938GC38V$"*'KV6Y,B>%)P>L;2,'A!4P)V8G)20'(
M3(GI2<'M`DC!X1Y%B<-,">E)B?6)]D@#M"00`0``23'-1#'H38G=2(V4`J'K
MV6Y,B=A)P>T;2,'@!4P)Z(G`2`'"3(G@2<'L`DC!X!Y!B=5,">!)B<R)R4DQ
MQ$4QX$V)[$Z-A`:AZ]EN3(GN2<'L&TC!Y@5,">:)]DP!QDV)V$G!ZP))P>`>
M08GT30G828G#2`.,)!@!``")P$TQPT@#A"0@`0``1#':38GC2(V,$:'KV6Y,
MB>))P>L;2,'B!4P)VHG22`'13(GJ2<'M`DC!XAY!B<M,">I-B<5%B<!,`X0D
M*`$``$DQU40Q[DV)W4B-M#"AZ]EN3(G82<'M&TC!X`5,">B)P$@!\$R)YDG!
M[`)(P>8>08G%3`GF28G4B=)(`Y0D,`$``$DQ]$0QX4V)[$V-A`BAZ]EN3(GI
M2<'L&TC!X05,">&)R4D!R$R)V4G!ZP)(P>$>18G$3`G928GSB?9),<M$,=A-
MB>-(`[0D.`$``$B-E`*AZ]EN3(G@2<'K&TC!X`5,"=A$C1P03(GH2<'M`DC!
MX!Y,">A)B<V)R4DQQ8G"13'H38G=3HV$!J'KV6Y,B=Y)P>T;2,'F!4P)[DR+
MK"1``0``1HTT!DV)X$G![`))P>`>30G@3`G`1(G&28G$2(G02"'P32'<20G$
MN-R\&X])`<5,`>E-B?5)`<Q,B?%)P>T;2,'A!4P)Z4F)]4$!S$R)V4G!ZP)(
MP>$>3`G908G+20G(32'P32'=30GH3(NL)$@!``!)`<5,`>I-B>5)`=!,B>))
MP>T;2,'B!4P)ZD:-+`),B?))P>X"2,'B'DP)\DV)WD&)T$@)T4TAQDPAX4P)
M\4R+M"10`0``20'&3`'V38GN2`'Q3(GN2<'N&TC!Y@5,"?9$C30.3(GF2<'L
M`DC!YAY,">9-B<2)\4@)\DDAS$PAZDP)XDR+I"18`0``20'$30'C38GT3`':
M38GS2<'C!4G![!M-">-%C20338GK2<'M`DG!XQY-">M)B<U$B=I,"=Y)(=5,
M(?9,">Y,BZPD8`$``$D!Q4T!Z$V)Y4P!QDV)X$G![1M)P>`%30GH18TL,$V)
M\$G![@))P>`>30GP28G61(G&30G#22'V32'C30GS3(NT)&@!``!)`<9,`?%-
MB>Y)`<M,B>E)P>X;2,'A!4P)\4:--!E,B>%)P>P"2,'A'DP)X4F)]$&)RTD)
MR$TAZ$TAW$T)X$R+I"1P`0``20'$3`'B38GT20'03(GR2<'L&TC!X@5,">)&
MC20"3(GJ2<'M`DC!XAY,">I-B=U!B=!("=%-(<5,(?%,">E,BZPD>`$``$D!
MQ4P![DV)Y4@!\4R)YDG![1M(P>8%3`GN1(TL#DR)]DG![@)(P>8>3`GV38G&
MB?%("?))(<Y,(>),"?),B[0D@`$``$D!QDT!\TV)[DP!VDV)ZTG!XP5)P>X;
M30GS18TT$TV)XTG![`))P>,>30GC28G,1(G:3`G>22'43"'N3`GF3(ND)(@!
M``!)`<1-`>!-B?1,`<9-B?!)P>P;2<'@!4T)X$6-)#!-B>A)P>T"2<'@'DT)
MZ$F)U42)QDT)PTDA]4TA\TT)ZTR+K"20`0``20'%3`'I38GE20'+3(GA2<'M
M&TC!X05,">E&C2P93(GQ2<'N`DC!X1Y,"?%)B?9)"<A!B<M-(=Y-(>!-"?!,
MB[0DF`$``$D!QDP!\DV)[DD!T$R)ZDG![AM(P>(%3`GR1HTT`DR)XDG![`)(
MP>(>3`GB38G<08G02`G132'$3"'I3`GA3(ND)*`!``!)`<1,`>9-B?1(`?%,
MB?9)P>P;2,'F!4P)YD2-)`Y,B>Y)P>T"2,'F'DP)[DV)Q8GQ2`GR22'-3"'R
M3`GJ3(NL)*@!``!)`<5-`>M-B>5,`=I-B>-)P>T;2<'C!4T)ZT6-+!--B?-)
MP>X"2<'C'DT)\TF)SD2)VDP)WDDAUDPAYDP)]DR+M"2P`0``20'&30'P38GN
M3`'&38GH2<'N&TG!X`5-"?!%C30P38G@2<'L`DG!X!Y-">!)B=1$B<9-"<-)
M(?1-(>M-">-,BZ0DN`$``$D!Q$P!X4V)]$D!RTR)\4G![!M(P>$%3`GA1HTD
M&4R)Z4G![0)(P>$>3`GI28GU08G+20G(32'P32'=30GH3(NL),`!``!)`<5,
M`>I-B>5)`=!,B>))P>T;2,'B!4P)ZD:-+`),B?))P>X"38G82,'B'DP)\D&)
MUD@)T4TA\$PAX4P)P4R+A"3(`0``20'`3`'&38GH2`'Q3(GN2<'H&TC!Y@5,
M"<9$C00.3(GF2<'L`DR)\4C!YAY,">9!B?1("?),(>%,(>I("<I(BXPDT`$`
M`$@!P4D!RTR)P4@#A"38`0``3`':38G#2,'A!4P!\$G!ZQM,"=F)R4@!RDR)
MZ4G![0)(P>$>08G33`GI38GE08G/2`G.32']3"'&3`GN38G=2`'P3(G>2<'M
M&TC!Y@5,">Z)]D@!\$R)QDG!Z`)(P>8>08G%20GPOM;!8LI,,<$QRDB+C"3@
M`0``2`'Q20',3(GI3`'B38GL2,'A!4G![!M,">&)R4@!RDR)V4C!X1Y)P>L"
M08G420G+3(G!38GF18G`3#'92<'N&S'(2(N,).@!``!(`?%)`<]*C0PX3(G@
M2,'@!4P)\(G`3(TT`4R)Z$G![0),B=E(P>`>18GW18G;20G%2(N$)/`!``!,
M,>E(`?`QRDR)^4P!P$C!Z1M(`<),B?A(P>`%2`G(2(N,)/@!``")P$@!PDR)
MX$@!\4G![`)(P>`>3`'938GK08G03`G@38G$18GM23'#2<'L&T4QWDZ-'#%,
MB<%(P>$%3`GAB<E)`<M,B?E)P>\"2,'A'D6)W$D)STB+C"0``@``2`'Q3`'I
M28G%B<!-,?U$,>I,C2P13(GB3(GA2,'I&TC!X@5("<I,B<%)P>@"B=)(P>$>
M20'52(N4)`@"``!,"<%-B?A),<A%B>Y%B?](`?)%,<-(`=!,B?).C0083(GP
M2,'J&TC!X`5("=!(B<J)R8G`20'`3(G@2<'L`DC!X!Y%B<-)"<1(BX0D$`(`
M`$PQXD@!\$$QU4R)VDP!^$D!Q4R)V$C!X`5(P>H;2`G03(GR2<'N`HG`2,'B
M'DD!Q4B+A"08`@``3`GR18GO2`'P2`'(3(GA18GD2#'103'(3(GY20'`3(GX
M2,'I&TC!X`5("<B)P$D!P$R)V$G!ZP)(P>`>18G&20G#2(N$)"`"``!,B?%(
MP>D;2`'P3`'@28G4B=)-,=Q%,>5.C20H3(GP2,'@!4@)R$B+C"0H`@``B<!)
M`<1,B?A(`?%)P>\"2,'@'D@!RDR)V46)Y4P)^$6)VT@QP4$QR$R)Z4D!T$R)
MZDC!Z1M(P>(%2`G*B=))`=!,B?))P>X"2,'B'D6)QTD)UDB+E"0P`@``3(GY
M2,'I&T@!\DP!VDF)PXG`33'S13'<3HT<(DR)^DC!X@5("<I,B>E)P>T"B=)(
MP>$>20'32(N4)#@"``!,">E%B=Q(`?)(`=!,B?)%B?9(,<I!,=!,B>))`<!,
MB>!(P>H;2,'@!4@)T$B)RHG)B<!)`<!,B?A)P>\"2,'@'D6)Q4D)QTB+A"1`
M`@``2`'P3#'Z3`'P03'33(GJ20'#3(GH2,'J&TC!X`5("=!,B>))P>P"B<!(
MP>(>20'#2(N$)$@"``!,">)%B=Y)B=1(`?!(`<A,B?E%B?](,=&)TD$QR$J-
M#`!,B?!-B?!)P>@;2,'@!4P)P(G`2`'!3(GH2<'M`DC!X!Y!B<A)"<5(BX0D
M4`(``$TQ[$@!\$4QXTV)Q$P!^$G![!M)`<-,B<!(P>`%3`G@B<!)`<-,B?!(
MP>`>2<'N`D6)W$P)\$R+M"18`@``20'V20'63(GJ18GM2#'",=%)C10.3(GA
M38GF2<'N&TC!X05,"?&)R4@!RDR)P4G!Z`)(P>$>08G620G(2(N,)&`"``!(
M`?%,`>E)B<6)P$TQQ44QZTV)]4D!RTR)\4G![1M(P>$%3`GIB<E)`<M,B>%)
MP>P"2,'A'D6)W4D)S$B+C"1H`@``2`'Q2`'(3(G!18G`3#'A,<I(C0P03(GH
M3(GJ2,'J&TC!X`5("=!,B?))P>X"2,'B'HG`20G62(N4)'`"``!(`<&)R$@!
M\DP!PDV)X$TQ\$4QPTF)P$P!VDF)PTG!X`5)P>L;30G828G#2,'H`DG!XQY!
M`=!,B>I)P>T"20G#2(N$)'@"``!(P>(>20G51(GB00';2`'P1`'M3(E?$$@!
MPDR)\$B);QA,,>@QP4B-!`I,B<),B<%%`<A(P>(%2,'I&TR)1PA("<H!T$$!
MPD0#=R!,B1=,B7<@2(N$)(@"``!(,P4-8```=1)(@<28`@``6UU!7$%=05Y!
M7\/H%,O__P\?0`!(@^P(OX````#H(LO__[J)J\WON?[<NIB^\.'2PTC'``$C
M16=(B5`(2(E($$C'0!AV5#(02(EP($C'0"@`````2,=`,`````#'0'@`````
M2(/$",-F9BX/'X0``````)!!5TACPD%628G&055!5$F)_%5)C6PD.%-(B?-(
M@^P(2(MW*$B+5S"-#,9(.?%(B4\H2(/2`$C!Z!U(`=!(B4<P2&-_>(7_=%9!
MO4````!(B=Y!*?U%.>Y%#T[N2`'O36/]3(GZZ+?-__]!BT0D>$0!Z$&)1"1X
M@_A`=!5(@\0(6UU!7$%=05Y!7\-F#Q]$``!,B>=%*>Y,`?OH\NC__T&#_C\/
MCMP```!!@^Y`18GW0<'O!D6)_4F#Q0%)P>4&20'=\P]O`TR)YTB#PT`/$44`
M\P]O2]`/$4T0\P]O4^`/$54@\P]O6_`/$5TPZ*#H__],.>MUS$'!YP9%*?Y)
M8\9(@_@(<EM)BU4`28E4)#A)BU0%^$B)5`7X2(U5"$B#XOA(*=5)*>U(`<5(
M@^7X2(/]"'(82(/E^#'`28M,!0!(B0P"2(/`"$@YZ'+N18ET)'A(@\0(6UU!
M7$%=05Y!7\.0J`1U*$B%P'3B00^V50!!B%0D.*@"=-1!#[=4!?YFB50%_NO'
M28G=Z7#___]!BU4`08E4)#A!BU0%_(E4!?SKJT%63(UV.$%505152(G]4TB+
M1BA(B?-$BV8H1(MN,$C!Z`.#X#]!#\Q!#\V-2`%(F,9$!CB`2&/!3`'P@_DX
M#XX@`0``ND`````IRHG1=`\QTHG6@\(!Q@0P`#G*<O-(B=_HBN?__V8/[\`/
M$4,X2<=&,`````!!#Q%&$$$/$48@1(EK<$B)WT2)8W3H8.?__TB+`TB)WTC!
MZ!B(10!(BP-(P>@0B$4!2(L#2,'H"(A%`DB+`XA%`TB+0PA(P>@8B$4$2(M#
M"$C!Z!"(105(BT,(2,'H"(A%!DB+0PB(10=(BT,02,'H&(A%"$B+0Q!(P>@0
MB$4)2(M#$$C!Z`B(10I(BT,0B$4+2(M#&$C!Z!B(10Q(BT,82,'H$(A%#4B+
M0QA(P>@(B$4.2(M#&(A%#TB+0R!(P>@8B$402(M#($C!Z!"(11%(BT,@2,'H
M"(A%$DB+0R!;B$4374%<05U!7NE,R/__NC@````Q_RG*@_H(<R[VP@1U:X72
M#X0!____Q@``]L("#X3U_O__,<EFB4P0_NGI_O__9@\?A```````B=%(QP``
M````2,=$"/@`````2(U("$B#X?A(*<@!PH/B^(/Z"`^"M?[__X/B^#'`B<:#
MP`A(B3PQ.=!R\^F>_O__QP``````QT00_`````#IB_[__TB+!8Q;``!(@_C_
M="152(GE4TB#[`B[&*U``/_02(/K"$B+`TB#^/]U\4B#Q`A;7</#`$B#[`CH
M@,[__TB#Q`C#````+@`N+@`E<R\E<P`O<')O8R]C=7)P<F]C+V9I;&4`1'EN
M84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4
M`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`)7,E<R5S`%!%4DPU3$E"`%!%
M4DQ,24(`4$523#5/4%0`4$523$E/`%!!4E])3DE424%,25I%1`!005)?4U!!
M5TY%1`!005)?0TQ%04X`4$%27T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,
M7T1%0E5'`%!!4E]'3$]"04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!
M3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`,0!,1%],24)205)97U!!5$@`55-%
M4@!365-414T`+W1M<"\`5$U01$E2`%1%35!$25(`5$5-4`!435``55-%4DY!
M344`)3`R>`!P87(M`"5S)7,E<R5S`%!!5$@`<&%R;``N<&%R`"5S)7-C86-H
M92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M)74E<P`8`'!E<FP`
M,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`U-@`M90`M+0`````````E<SH@
M8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE
M<G)N;STE:2D*```````````````````E<SH@<')I=F%T92!S=6)D:7)E8W1O
M<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y
M;W5R(&]P97)A=&EO;BD*````````56YA8FQE('1O(&-R96%T92!C86-H92!D
M:7)E8W1O<GD``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE
M('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``````````&5V
M86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P
M.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A
M<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D0T%#
M2$5?;6%R:V5R+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!
M1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@
M(R!P86-K*").(BD*)&-A8VAE7VUA<FME<B`](")<,$-!0TA%(CL*)&-A8VAE
M7VYA;65?<VEZ92`](#0P.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY("@D
M9F@I(#T@0%\["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D8G5F
M.PIM>2`D<VEZ92`]("US("1F:#L*;7D@)'!O<R`]("1S:7IE("T@)'-I>F4@
M)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z("1P;W,@:7,@82!M=6QT:7!L
M92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O<R`^/2`P*2!["G-E96L@)&9H
M+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG
M=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!
M4E]-04=)0RDI(#X](#`I('L*)'!O<R`K/2`D:3L*<F5T=7)N("1P;W,["GT*
M)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?
M=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$
M('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`[
M"G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*
M;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M
M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*
M1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@
M=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD
M("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N
M97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@
M)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^
M9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD
M>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@
M)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@
M7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*
M8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^
M+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W
M;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F
M:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4
M*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?
M<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT[
M"FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@
M/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7
M:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]
M/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T
M7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B
M72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@
M/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P
M;W,I.PI-04=)0SH@>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*
M=6YL97-S("AO<&5N(%]&2"P@)SPZ<F%W)RP@)'!R;V=N86UE*2!["F]U=',H
M<7%;0V%N)W0@<F5A9"!F<F]M(&9I;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N
M)W0@=7-E("0A(&AE<F4@87,@:70@<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-
M04=)0SL*?0IM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D[
M"FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G
M:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE("(D<')O9VYA;64B72D[
M"FQA<W0@34%'24,["GT*;W5T<R@B1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET
M:6]N("1M86=I8U]P;W,B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,
M15]O9F9S971?<VEZ92P@,#L*<F5A9"!?1D@L("1B=68L("1&24Q%7V]F9G-E
M=%]S:7IE.PIM>2`D;V9F<V5T(#T@=6YP86-K*").(BP@)&)U9BD["F]U=',H
M(D]F9G-E="!F<F]M('-T87)T(&]F($9)3$5S(&ES("1O9F9S970B*3L*<V5E
M:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M("1O9F9S
M970L(#`["B1D871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T
M.PIR96%D(%]&2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C(')E860@=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,
M12(I('L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A
M8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5
M;G!A8VMI;F<@1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D
M9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F
M.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H
M+BHI*%PN+BHI?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U
M9BP@=6YP86-K*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D
M97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@
M/2!?<V%V95]A<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS
M:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%
M3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&)A
M<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N
M86UE7&XB*3L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2![
M"F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L
M"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D
M8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D
M=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4[
M"FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL
M97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.
M0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.
M5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM
M>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C
M<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R
M:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F
M:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[
M8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL
M96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE
M('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*
M?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L
M92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U
M:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@
M17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R
M*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H
M<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD
M9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I
M;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*
M96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E
M8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I
M;&5N86UE?3L*?0IU;FQE<W,@*"1B=68@97$@(E!+7#`P,UPP,#0B*2!["F]U
M=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F:6QE
M("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@/2`H
M=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*
M?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C
M86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N
M:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"FEF("@A
M)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F
M('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R
M"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P
M87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E
M<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%04%]21553
M17T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA
M=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP
M72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H
M)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D
M,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G
M*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G
M*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@
M/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L
M;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF
M("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92!Q
M<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A73L*?0IE;'-I9B`H)#$@
M97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII
M9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!
M4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)0
M05(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T
M.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.
M0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z
M.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ
M4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD
M969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1P87(@;W(@
M9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P87(B.B`D(5T["F)L97-S
M*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*
M*"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H
M:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;17)R;W(@<F5A9&EN9R!Z
M:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A7W!A<B`](&1O('L*:68@
M*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL
M)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3
M+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*
M:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P:"P@)SPZ<F%W)RP@)'!A
M<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL92`B)'!A<B(Z("0A73L*
M;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I92!Q<5LB)'!A<B(@:7,@
M;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*
M8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@.PIM>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!5"@I('P@24\Z.D9I
M;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI
M(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H
M+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H
M9&5F:6YE9"`D9&%T85]P;W,I('L*<F5A9"!?1D@L("1L;V%D97(L("1D871A
M7W!O<SL*?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?
M1D@^.PI]"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^
M("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13
M=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@
M)#`I.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["FUY("1P87)?8VQE86X@
M/2`B/3$B.PIM>2`D<&%S<U]P87)?8VQE86X@/2!U8R`B7U]P87-S7W!A<E]C
M;&5A;E]?(CL*)&QO861E<B`]?B!S>R@_/#TD>W!A<W-?<&%R7V-L96%N?2DH
M("LI?0I[)'!A<E]C;&5A;B`N("@B("(@>"`H;&5N9W1H*"0Q*2`M(&QE;F=T
M:"@D<&%R7V-L96%N*2DI?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD*;W(@
M9&EE('%Q6T5R<F]R('=R:71I;F<@;&]A9&5R('1O("(D;W5T(CH@)"%=.PII
M9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U
M;&5S*"D["FUY($!I;F,@/2!G<F5P('L@(2]"4T1004XO('T*9W)E<"!["B@D
M8G5N9&QE(&YE("=S:71E)RD@;W(**"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA
M<F-H;&EB97AP?2!A;F0*)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E
M>'!]*3L*?2!`24Y#.PIS?"\K?"]\9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*
M;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S
M:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O
M;F9I9SHZ0V]N9FEG>VQI8E]E>'1].R`@("`@("`@(",@6%A8(&QI8E]E>'0@
M=G,@9&QE>'0@/PIM>2`E=W)I='1E;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T
M(&ME>7,@)69I;&5S*2!["FUY("@D9FEL92P@)&YA;64I.PII9B`H9&5F:6YE
M9"AM>2`D9F,@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH
M)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H
M(&UY("1D:7(@*$!I;F,I('L*:68@*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ
M*21\:2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*
M:68@*"1K97D@/7X@;7Q>+VQO861E<B];7B]=*R\H+BHI)'PI('L*:68@*&UY
M("1R968@/2`D36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA;64I(#T@
M*"1R968L("0Q*3L*;&%S=#L*?0II9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL
M92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE
M>'0@=6YL97-S(&1E9FEN960@)&YA;64["FYE>'0@:68@)'=R:71T96Y[)&YA
M;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1
M)&QI8E]E>'1<120O:3L*;W5T<RAS<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B
M)7,B+BXN72P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D[
M"FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F
M:6QE+3Y[8G5F?3L*?0IE;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M
M>2`D=&@L("<\.G)A=R<L("1F:6QE(&]R(&1I92!Q<5M#86XG="!R96%D("(D
M9FEL92(Z("0A73L*)&-O;G1E;G0@/2`\)'1H/CL*8VQO<V4@)'1H.PI005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E
M9#XO)&YA;64B*0II9B`A)$5.5GM005)?5D520D%424U](&%N9"`D;F%M92`]
M?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E
M;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92P@)&YA;64I.PI]"B1F
M:"T^<')I;G0H(D9)3$4B+`IP86-K*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI
M+`IS<')I;G1F*"(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#
M,S(H)&-O;G1E;G0I+"`D;F%M92DL"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E
M;G0I*2P*)&-O;G1E;G0I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&5M8F5D
M9&5D($9)3$4@=&\@(B1O=70B.B`D(5T["F]U=',H<7%;5W)I='1E;B!A<R`B
M)&YA;64B72D["GT*?0II9B`H)'II<"D@>PHD>FEP+3YW<FET951O1FEL94AA
M;F1L92@D9F@I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TL*;W(@9&EE('%Q6T5R
M<F]R('=R:71I;F<@>FEP('!A<G0@;V8@(B1O=70B73L*?0HD8V%C:&5?;F%M
M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*
M:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI
M6SE=*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N(&UY
M("1T:"P@(CPZ<F%W(BP@)&]U=#L*)&-T>"T^861D9FEL92@D=&@I.PIC;&]S
M92`D=&@["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H
M95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D
M8V%C:&5?;F%M92D["B1C86-H95]N86UE("X]("1C86-H95]M87)K97(["FUY
M("1O9F9S970@/2`D9F@M/G1E;&P@*R!L96YG=&@H)&-A8VAE7VYA;64I("T@
M;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`IP86-K
M*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I"B8F("1F:"T^8VQO<V4*;W(@
M9&EE('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*
M8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN
M960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL
M93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@(",@07)C
M:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P
M96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE
M9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM
M>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I
M;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P
M<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P
M,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H
M97LD<')O9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB
M*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@
M<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M
M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY
M("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S
M<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#
M;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE
M?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@
M)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-
M4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?
M(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K
M:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S
M(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I
M;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M
M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV
M93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z
M:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T
M7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2
M.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!
M4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO
M9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@
M72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@
M)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A
M=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64[
M"FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE
M.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0
M871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T
M:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO
M9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U
M:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S
M.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(
M96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD[
M"G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL
M93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R
M.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E
M($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R
M8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005([
M"G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R
M.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E
M<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R
M97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E
M.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.
M86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E
M(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS
M=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]
M(&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@
M)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1?
M?2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL
M"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE
M9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA
M;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@
M:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA
M;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I
M9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L
M<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]
M('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L
M:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP
M9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]
M*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@
M)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@
M(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P
M87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM
M("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*"1C86-H95]M87)K97(I+"`P
M.PIM>2`D8G5F.PIR96%D("1F:"P@)&)U9BP@;&5N9W1H*"1C86-H95]M87)K
M97(I.PII9B`H)&)U9B!E<2`D8V%C:&5?;6%R:V5R*2!["G-E96L@)&9H+"`D
M;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H)&-A8VAE
M7VUA<FME<BD*+2`D8V%C:&5?;F%M95]S:7IE+"`P.PIR96%D("1F:"P@)&)U
M9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]?B!S+UPP+R]G.PHD8V%C:&5?
M9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO<V4@)&9H.PI]"FEF("@A)&-A
M8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E;7`M)"0B.PHD14Y6>U!!4E]#
M3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D<WES>U]D96QI;7TD8V%C:&5?
M9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34["B1%3E9[4$%27U1%35!](#T@
M)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM005)?
M5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@7W-A
M=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\["FUY
M("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE("1F
M=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*;7D@
M)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T96UP;F%M92D*)B8@*'!R:6YT
M("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D9F@I"F]R(&1I92!Q<5M%<G)O
M<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T["F-H;6]D("1M;V1E+"`D=&5M
M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U
M;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN
M86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM0
M05)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO
M*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D
M14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]4
M14U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R
M:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI("L@,2D["GT*:68@*"$D
M14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D<WES>U]D
M96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M
M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)'-Y
M<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[7V5X97T["G)E='5R;CL*
M?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)'-Y<WMP871H7W-E<'U<
M12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-
M4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@<R]<421S
M>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L
M:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T*0II9B`M<R`B)&1I<B1S
M>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB.PHH*"1P<F]G;F%M92`]
M("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D
M9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N
M86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*
M:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`\(#`I('L*)'!R
M;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@
M/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H
M9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@
M<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<
M421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L:6U]+SL*)$5.5GM005)?
M4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*
M:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX[
M"GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ
M=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@
M*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*?0IF;W(@*'%W+R!435!$25(@
M5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[(E!!4E\D7R)](#T@)$5.5GLB
M4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D14Y6>R)005)?1TQ/0D%,7R1?
M(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#
M3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D
M;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@
M(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U
M<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1?
M?2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E
M;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G
M92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN
M9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ
M($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@
M9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@
M)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E4
M7UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D
M0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>
M7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?
M15)23U(["C$["E]?14Y$7U\*`````'!E<FQX<VDN8P`````````4````````
M``%Z4@`!>!`!&PP'")`!``!,````'````."-___&`````$(.$(\"0@X8C@-"
M#B"-!$(.*(P%00XPA@9!#CB#!T0.0`)L"@XX1`XP00XH0@X@0@X80@X00@X(
M20L``````"0```!L````8([__WL`````00X0@P)'#B`";`H.$$$."$$+````
M``!,````E````+B.__\W`@```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9$
M#CB#!T<.8`,5`0H..$$.,$$.*$(.($(.&$(.$$(."$$+`````#P```#D````
MJ)#__T$!````0@X0C0)"#AB,`T$.((8$00XH@P5'#L`!>@H.*$$.($$.&$(.
M$$(."$,+```````D````)`$``+B1__^!`````$$.$(,"2@Z@`0)O"@X000X(
M00L`````/````$P!```@DO__R0````!"#A"-`DH.&(P#00X@A@1)#BB#!4<.
MP`@">@H.*$$.($$.&$(.$$(."$,+`````"P```",`0``L)+__ZT`````00X0
M@P)*#J`(`F\*#A!!#@A%"UT*#A!&#@A%"P```!0```"\`0``,)/__RH`````
M1`X080X(`!0```#4`0``2)/__T0`````1`X0>PX(`!0```#L`0``@)/__P,`
M`````````````#P````$`@``>)/__^\!````0@X0C0)*#AB,`T$.((8$00XH
M@P5*#L`)`EP*#BA!#B!!#AA"#A!"#@A&"P`````<````1`(``"B5__\B````
M`$$.$(,"7`X(`````````"0```!D`@``.)7__T0`````2PX0@P)8PPX(70X0
M@P)##@@````````<````C`(``&"5__]<`0```$0.(`,B`0H."$H+`````!P`
M``"L`@``H);__VH`````1`X@:PH."$$+````````%````,P"``#PEO__'0``
M``!$#A!8#@@`-````.0"``#XEO__L0````!"#A",`D$.&(8#20X@@P1$#C`"
M1@H.($$.&$$.$$(."$8+``````!<````'`,``("7__\\!P```$(.$(X"0@X8
MC0-*#B",!$$.*(8%00XP@P9'#I"#`@.4`@H.,$$.*$$.($(.&$(.$$(."$$+
M`ZL!#IB#`DL.H(,"6PZ8@P)!#I"#`@`````L````?`,``&">__]O`@```$$.
M$(8"00X8@P-$#C`#O`$*#AA!#A!!#@A!"P`````T````K`,``*"@__]>````
M`$$.$(8"00X8@P-'#B`"00H.&$$.$$$."$0+1`X81`X000X(`````"0```#D
M`P``>(7__^P!````00X0@P)$#D`#B`$*#A!!#@A!"P````!,````#`0``+"@
M__\,%@```$(.$(\"1@X8C@-"#B"-!$(.*(P%00XPA@9!#CB#!T<.T`4#YQ4*
M#CA!#C!!#BA"#B!"#AA"#A!"#@A!"P```!0```!<!```<+;__U0`````1`X0
M`D\."&0```!T!```N+;__Z`!````0@X0CP)%#AB.`T4.((T$0@XHC`5$#C"&
M!D8..(,'1PY``F`*#CA!#C!!#BA"#B!"#AA"#A!"#@A'"P+$"@XX00XP00XH
M0@X@0@X80@X00@X(0@L`````1````-P$``#PM___]0$```!"#A".`D8.&(T#
M0@X@C`1!#BB&!40.,(,&`T8!"@XH1`X@0@X80@X00@X(10L`````````````
M)````"0%``!(@/__\`,````.$$8.&$H/"W<(@``_&CLJ,R0B```````````!
M&P,[L/K__QH````D@/__U/___Q2$__^4_O__M(C__\SZ__^$B?__'/O__P2*
M__]$^___1(S__Y3[__^4C?__U/O__R2.___\^___]([__SS\__^DC___;/S_
M_]2/__^$_/__))#__YS\__\TD/__M/S__R22___T_/__5)+__Q3]__^DDO__
M//W__P24__]<_?__=)3__WS]__^4E/__E/W__U25___,_?__E)S__RS^__\$
MG___7/[__W2?__^\_O__A+7__PS____DM?__)/___X2W__^,____`P``````
M``#PJD````````(`````````T`4````````7`````````$`20```````%```
M```````'``````````<`````````R!%````````(`````````'@`````````
M"0`````````8`````````!4````````````````````&`````````%`"0```
M````"P`````````8``````````4`````````.`M````````*`````````*0$
M````````]?[_;P````#@#T````````$`````````(00````````!````````
M`#$$`````````0````````!!!`````````$`````````3`0````````!````
M`````%8$`````````0````````!D!`````````$`````````,P`````````,
M`````````!`80```````#0````````"X44```````!T`````````<00`````
M``#P__]O`````-000```````_O__;P````"4$4```````/___V\``````0``
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````.BH0````````````````````````````$88
M0```````5AA```````!F&$```````'880```````AAA```````"6&$``````
M`*880```````MAA```````#&&$```````-880```````YAA```````#V&$``
M``````890```````%AE````````F&4```````#890```````1AE```````!6
M&4```````&890```````=AE```````"&&4```````)890```````IAE`````
M``"V&4```````,890```````UAE```````#F&4```````/890```````!AI`
M```````6&D```````"8:0```````-AI```````!&&D```````%8:0```````
M9AI```````!V&D```````(8:0```````EAI```````"F&D```````+8:0```
M````QAI```````#6&D```````.8:0```````]AI````````&&T```````!8;
M0```````)AM````````V&T```````$8;0```````5AM```````!F&T``````
M`'8;0```````AAM```````"6&T```````*8;0```````MAM```````#&&T``
M`````-8;0```````YAM```````#V&T````````8<0```````%AQ```````#(
M44``````````````````_____P````"X5$```````/__________````````
M``#__________P```````````$=#0SH@."XS(%M$<F%G;VY&;'E=(%)E;&5A
M<V4O,C`Q.2TP,BTR,@`````$````"0````0```!'3E4`9V]L9"`Q+C$V````
M`"YT97AT`"YG;W0`+F-O;6UE;G0`+F=O="YP;'0`+G)E;&$N<&QT`"YI;FET
M`"YB<W,`+F1T;W)S`"YC=&]R<P`N9'EN<W1R`"YE:%]F<F%M95]H9'(`+F=N
M=2YV97)S:6]N7W(`+FEN=&5R<``N<F5L82YD>6X`+F=N=2YV97)S:6]N`"YN
M;W1E+F=N=2YG;VQD+79E<G-I;VX`+F1Y;G-Y;0`N9FEN:0`N9VYU+FAA<V@`
M+FYO=&4N=&%G`"YE:%]F<F%M90`N=&U?8VQO;F5?=&%B;&4`+F1Y;F%M:6,`
M+G-H<W1R=&%B`"YR;V1A=&$`+F1A=&$`````````````````````````````
M````````````````````````````````````````````````````````````
M``````!F`````0````(```````````)``````````@```````!4`````````
M```````````!````````````````````M`````<````"`````````!@"0```
M````&`(````````X````````````````````!````````````````````)P`
M```+`````@````````!0`D```````%`"````````Z`@````````$`````0``
M``@`````````&`````````!!`````P````(`````````.`M````````X"P``
M`````*0$```````````````````!````````````````````J@```/;__V\"
M`````````.`/0```````X`\```````#T``````````,`````````"```````
M`````````````'@```#___]O`@````````#4$$```````-00````````O@``
M```````#``````````(``````````@````````!7````_O__;P(`````````
ME!%```````"4$0```````#``````````!`````$````$````````````````
M````;@````0````"`````````,@10```````R!$```````!X``````````,`
M````````"``````````8`````````!X````$````0@````````!`$D``````
M`$`2````````T`4````````#````"P````@`````````&``````````H````
M`0````8`````````$!A````````0&````````!,````````````````````$
M````````````````````(P````$````&`````````#`80```````,!@`````
M``#P`P``````````````````$``````````0``````````$````!````!@``
M```````@'$```````"`<````````ES4``````````````````!``````````
M``````````"D`````0````8`````````N%%```````"X40````````X`````
M```````````````$````````````````````ZP````$````"`````````,A1
M0```````R%$```````#R0```````````````````"```````````````````
M`+X````!``!P`@````````#`DD```````,"2````````3`4`````````````
M``````@```````````````````!)`````0``<`(`````````#)A````````,
MF````````-P````````````````````$````````````````````V`````8`
M```#`````````.BH0```````Z)@``````````@````````0`````````"```
M```````0``````````<````!`````P````````#HJD```````.B:````````
M"`````````````````````@````````````````````5`````0````,`````
M````\*I```````#PF@````````@"```````````````````(````````````
M````````\P````$````#`````````/BL0```````^)P````````@````````
M````````````"````````````````````#H````!`````P`````````8K4``
M`````!B=````````$`````````````````````@````````````````````S
M`````0````,`````````**U````````HG0```````!``````````````````
M```(````````````````````R`````$````#`````````#BM0```````.)T`
M````````````````````````````"````````````````````"X````(````
M`P````````!`K4```````#B=````````H0```````````````````"``````
M```````````````,`````0```#`````````````````````XG0```````"D`
M```````````````````!``````````$`````````A0````<`````````````
M````````````9)T````````<````````````````````!```````````````
M`````.$````#`````````````````````````("=````````^0``````````
7``````````$`````````````````````
